@@ -20,9 +20,9 @@ summary.run_model <- function(object, threshold = NULL, ...) {
   }
   
   res_values <- get_model_results(object) %>% 
-    dplyr::select_(
-      ~ - .cost,
-      ~ - .effect
+    dplyr::select(
+      -.data$.cost,
+      -.data$.effect
     ) %>% 
     as.data.frame()
   
@@ -34,7 +34,7 @@ summary.run_model <- function(object, threshold = NULL, ...) {
     
     res_nmb <- object %>% 
       scale.run_model(center = FALSE) %>% 
-      dplyr::select_(".strategy_names", ".cost", ".effect") %>% 
+      dplyr::select(.data$.strategy_names, .data$.cost, .data$.effect) %>% 
       as.data.frame()
     
     res_nmb_strat <- character()
@@ -219,9 +219,9 @@ print.summary_run_model <- function(x, ...) {
 print_results <- function(res_values, res_comp, res_nmb) {
   cat("Values:\n\n")
   rownames(res_values) <- res_values$.strategy_names
-  res_values <- dplyr::select_(res_values,
-                               ~ - .strategy_names,
-                               ~ - .n_indiv)
+  res_values <- dplyr::select(res_values,
+                              -.data$.strategy_names,
+                              -.data$.n_indiv)
   print(res_values)
   
   if (! is.null(res_nmb)) {
@@ -229,12 +229,12 @@ print_results <- function(res_values, res_comp, res_nmb) {
     .strategy_names <- res_nmb$.strategy_names
     f <- function(x) x - min(x)
     res_nmb <- res_nmb %>% 
-      dplyr::select_(
-        ~ - .strategy_names,
-        ~ - .cost,
-        ~ - .effect
+      dplyr::select(
+        -.data$.strategy_names,
+        -.data$.cost,
+        -.data$.effect
       ) %>% 
-      dplyr::mutate_all(dplyr::funs(f))
+      dplyr::mutate_all(f)
     
     rownames(res_nmb) <- .strategy_names
     print(res_nmb)
@@ -247,8 +247,8 @@ print_results <- function(res_values, res_comp, res_nmb) {
     
     rownames(res_comp) <- res_comp$.strategy_names
     res_comp <- res_comp %>% 
-      dplyr::select_(".dcost", ".deffect",
-                     ".icer", ".dref")
+      dplyr::select(.data$.dcost, .data$.deffect,
+                    .data$.icer, .data$.dref)
     res_comp$.icer <- format(res_comp$.icer)
     res_comp$.icer[res_comp$.icer == "NA"] <- "-"
     res_comp <- res_comp[-1, ]
